Package: ncRNAtools
Type: Package
Title: An R toolkit for non-coding RNA
Version: 1.22.1
Date: 2021-06-27
Authors@R: c(
    person("Lara", "Selles Vidal", email = "lara.selles@oist.jp", role = c("cre", "aut"), comment = c(ORCID = "0000-0003-2537-6824")),
    person("Rafael", "Ayala", email = "rafael.ayala@oist.jp", role = "aut", comment = c(ORCID = "0000-0002-9332-4623")),
    person("Guy-Bart", "Stan", email = "g.stan@imperial.ac.uk", role = "aut", comment = c(ORCID = "0000-0002-5560-902X")),
    person("Rodrigo", "Ledesma-Amaro", email = "r.ledesma-amaro@imperial.ac.uk", role = "aut", comment = c(ORCID = "0000-0003-2631-5898")))
Description: ncRNAtools provides a set of basic tools for handling and 
    analyzing non-coding RNAs. These include tools to access the RNAcentral
    database and to predict and visualize the secondary structure of non-coding
    RNAs. The package also provides tools to read, write and interconvert the 
    file formats most commonly used for representing such secondary structures.
License: GPL-3
Imports: httr, xml2, utils, methods, grDevices, ggplot2, IRanges,
        GenomicRanges, S4Vectors
Suggests: knitr, BiocStyle, rmarkdown, RUnit, BiocGenerics
VignetteBuilder: knitr
biocViews: FunctionalGenomics, DataImport, ThirdPartyClient,
        Visualization, StructuralPrediction
NeedsCompilation: no
Encoding: UTF-8
BugReports: https://github.com/LaraSellesVidal/ncRNAtools/issues
git_url: https://git.bioconductor.org/packages/ncRNAtools
git_branch: RELEASE_3_23
git_last_commit: bbd3081
git_last_commit_date: 2026-04-29
Repository: Bioconductor 3.23
Date/Publication: 2026-04-30
Packaged: 2026-04-30 23:14:06 UTC; biocbuild
Author: Lara Selles Vidal [cre, aut] (ORCID:
    <https://orcid.org/0000-0003-2537-6824>),
  Rafael Ayala [aut] (ORCID: <https://orcid.org/0000-0002-9332-4623>),
  Guy-Bart Stan [aut] (ORCID: <https://orcid.org/0000-0002-5560-902X>),
  Rodrigo Ledesma-Amaro [aut] (ORCID:
    <https://orcid.org/0000-0003-2631-5898>)
Maintainer: Lara Selles Vidal <lara.selles@oist.jp>
